diff src/org/tmatesoft/hg/core/HgLogCommand.java @ 249:4c3b9f679412

Deprecated HgLogCommand.FileRevision gone, top-level HgFileRevision is bright and shiny replacement
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Fri, 12 Aug 2011 18:58:16 +0200
parents 6e1373b54e9b
children 9ef71bd26db1
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/core/HgLogCommand.java	Fri Aug 12 18:48:57 2011 +0200
+++ b/src/org/tmatesoft/hg/core/HgLogCommand.java	Fri Aug 12 18:58:16 2011 +0200
@@ -18,7 +18,6 @@
 
 import static org.tmatesoft.hg.repo.HgRepository.TIP;
 
-import java.io.IOException;
 import java.util.Calendar;
 import java.util.Collections;
 import java.util.ConcurrentModificationException;
@@ -31,7 +30,6 @@
 import org.tmatesoft.hg.repo.HgChangelog.RawChangeset;
 import org.tmatesoft.hg.repo.HgDataFile;
 import org.tmatesoft.hg.repo.HgRepository;
-import org.tmatesoft.hg.util.ByteChannel;
 import org.tmatesoft.hg.util.CancelledException;
 import org.tmatesoft.hg.util.Path;
 import org.tmatesoft.hg.util.ProgressSupport;
@@ -288,11 +286,11 @@
 	
 	/**
 	 * When {@link HgLogCommand} is executed against file, handler passed to {@link HgLogCommand#execute(HgChangesetHandler)} may optionally
 	 * implement this interface to get information about file renames. Method {@link #copy(FileRevision, FileRevision)} would
 	 * get invoked prior any changeset of the original file (if file history being followed) is reported via {@link #next(HgChangeset)}.
 	 * 
 	 * For {@link HgLogCommand#file(Path, boolean)} with renamed file path and follow argument set to false, 
 	 * {@link #copy(FileRevision, FileRevision)} would be invoked for the first copy/rename in the history of the file, but not 
 	 * followed by any changesets. 
 	 *
 	 * @author Artem Tikhomirov
@@ -300,7 +298,7 @@
 	 */
 	public interface FileHistoryHandler extends HgChangesetHandler {
 		// XXX perhaps, should distinguish copy from rename? And what about merged revisions and following them?
-		void copy(FileRevision from, FileRevision to);
+		void copy(HgFileRevision from, HgFileRevision to);
 	}
 	
 	public static class CollectHandler implements HgChangesetHandler {
@@ -314,14 +312,4 @@
 			result.add(changeset.clone());
 		}
 	}
-
-	/**
-	 * @deprecated pulled up, use {@link HgFileRevision} instead.
-	 */
-	@Deprecated
-	public interface FileRevision {
-		public abstract Path getPath();
-		public abstract Nodeid getRevision();
-		public abstract void putContentTo(ByteChannel sink) throws HgDataStreamException, CancelledException;
-	}
 }
@@ -288,11 +286,11 @@
 	/**
 	 * When {@link HgLogCommand} is executed against file, handler passed to {@link HgLogCommand#execute(HgChangesetHandler)} may optionally
-	 * implement this interface to get information about file renames. Method {@link #copy(FileRevision, FileRevision)} would
+	 * implement this interface to get information about file renames. Method {@link #copy(HgFileRevision, HgFileRevision)} would
 	 * get invoked prior any changeset of the original file (if file history being followed) is reported via {@link #next(HgChangeset)}.
 	 * 
@@ -288,11 +286,11 @@
 	 * 
 	 * For {@link HgLogCommand#file(Path, boolean)} with renamed file path and follow argument set to false, 
-	 * {@link #copy(FileRevision, FileRevision)} would be invoked for the first copy/rename in the history of the file, but not 
+	 * {@link #copy(HgFileRevision, HgFileRevision)} would be invoked for the first copy/rename in the history of the file, but not 
 	 * followed by any changesets. 
 	 *